@@ -40,7 +40,7 @@ from kb_runner_storage import KBRunner_Storage
 from kb_scheduler import KBScheduler
 
 import keystoneauth1
-from keystoneclient.v2_0 import client as keystoneclient
+from keystoneclient import client as keystoneclient
 
 import log as logging
 from neutronclient.neutron import client as neutronclient
@@ -615,7 +615,8 @@ class KloudBuster(object):
             self.kb_runner = KBRunner_HTTP(client_list, self.client_cfg,
                                            self.single_cloud)
 
-        self.kb_runner.setup_redis(self.kb_proxy.fip_ip or self.kb_proxy.fixed_ip)
+        self.kb_runner.setup_redis(self.kb_proxy.fip_ip or self.kb_proxy.fixed_ip,
+                                   timeout=self.client_cfg.proxy_timeout_sec)
         if self.client_cfg.progression['enabled'] and not self.multicast_mode:
             log_info = "Progression run is enabled, KloudBuster will schedule " \
                        "multiple runs as listed:"
@@ -686,9 +687,10 @@ class KloudBuster(object):
             for run_result in self.kb_runner.run(test_only, runlabel):
                 if not self.multicast_mode or len(self.final_result['kb_result']) == 0:
                     self.final_result['kb_result'].append(self.kb_runner.tool_result)
-            tsdb_result = self.tsdb_connector.get_results(start_time=start_time)
-            if tsdb_result:
-                self.final_result['tsdb'] = tsdb_result
+            if self.tsdb_connector:
+                tsdb_result = self.tsdb_connector.get_results(start_time=start_time)
+                if tsdb_result:
+                    self.final_result['tsdb'] = tsdb_result
             LOG.info('SUMMARY: %s' % self.final_result)
             if not self.interactive:
                 break
